=============
CLI reference
=============


os-inject-fault
---------------

.. program-output:: os-inject-fault --help


os-faults
---------

.. program-output:: os-faults --help


os-faults verify
----------------

.. program-output:: os-faults verify --help


os-faults discover
------------------

.. program-output:: os-faults discover --help


os-faults nodes
---------------

.. program-output:: os-faults nodes --help


os-faults drivers
-----------------

.. program-output:: os-faults drivers --help
